// Google Cloud Messaging (GCM)
// https://console.developers.google.com/project

// Cordova Plugin
//https://github.com/phonegap/phonegap-plugin-push
//1) cordova plugin add phonegap-plugin-push
//
//2) cordova plugin add cordova-plugin-device


var gcmPush;
var gcmKey;
var gcmBaseUrl  = 'http://www.bisnes-emas.com/';

function isGCM(id)
{
   // checking for current session   

   if(typeof(Storage)!="undefined") 
   {
      if ( (localStorage.getItem("gcm_id")==null) || 
	       (localStorage.getItem("gcm_id")=='undefined') ||
		   (localStorage.getItem("gcm_id")=='') )
	  {
	      return false;
	  }
	  else
	  {
	     if (id != localStorage.getItem("gcm_id")) // if mismatch
		 {
		    return false;
		 }
	     else
		 {
	        return true; // GCM ID is already created
		 }
	  }
   }
	else
	{
	   return false;
	}
}

function setGCM(id)
{
   localStorage.setItem("gcm_id", id);
}

function resetGCM()
{
  localStorage.setItem("gcm_id",null);
}

function ajaxUrlGCM(baseUrl)
{
  // gcmBaseUrl  - for ajax query to database server
   gcmBaseUrl = baseUrl;
}

function initGCM(gcmSenderID)
{ 
  // gcmSenderID - refer to Project Number in GCM project

  gcmPush = PushNotification.init({
            "android": { "senderID": gcmSenderID },
            "ios": {"alert": "true", "badge": "true", "sound": "true"}, 
            "windows": {} 
        });
						
	    onGCMReg();
	 
        gcmPush.on('error', function(e) {
           // console.log("push error");
        });
}

function onGCMReg()
{  
     gcmPush.on('registration', function(data)
	    {
		   gcmKey = data.registrationId;
			
	       // alert('registered ' + gcmKey + ' - isGCM: ' + isGCM(gcmKey));
			
			// store at the server side in database
	        // Check if ID already been stored in the local storage before
	        // this. 
	        // To avoid app keep sending same GCM ID to the back end server
	   
	        if (isGCM(gcmKey) != true) // not been created created
	           ajaxGCMAddUser();
       });
}

// SAMPLE FUNCTION
function sampleNotify()
{
      gcmPush.on('notification', function(data) 
	  {	   
		   alert(data.message);
			 
		   // data.message,
           // data.title,
           // data.count,
           // data.sound,
           // data.image,
           // data.additionalData
			
            gcmPush.finish(function () {
              //  console.log('finish successfully called');
            });
        }); // notification
}


// THIS FUNCTION NEEDS TO BE CALLED IN THE
// "deviceready" event
// and passing the function name to be called 
// when notification message arrived

function notifyGCM(func)
{
   gcmPush.on('notification', func); // notification
}

// THIS FUNCTION MAYBE CALLED INSIDE THE
// notification function

function finishGCM()
{
  gcmPush.finish(function () {
              //  console.log('finish successfully called');
            });	
}

function offGCMReg()
{
    gcmPush.unregister(function() {
   // console.log('success');
         ajaxGCMDelUser();
                             }, function() {
    //console.log('error');
});
}

// post to server to add gcm user
function ajaxGCMAddUser()
{ 
	  var formData = 'userid=' + gcmKey + '&devicePlatform=' + device.platform  +
	                 '&deviceVersion=' + device.version + '&deviceModel=' + device.model +
					 '&deviceUuid=' + device.uuid;
					 
	   var urlData  = gcmBaseUrl + 'gcm-add.php';
		 
	 $.ajax({
	   type: "POST", 
       url: urlData,
	   dataType: "xml",
	   data: formData,
	   success: onSuccessGCMRegister,
	   error: onErrorGCMRegister
        });

        return false;
}
   
function onSuccessGCMRegister(data)
{
   var regstatus;
   var errmsg;
   var dbmsg;
   
   var $xml   = $( data );
   	 
   $($xml).find("register").each(function () {
   
	   regstatus   = $(this).find("status").text();
	   errmsg      = $(this).find("errormsg").text();
	   dbmsg       = $(this).find("dbmsg").text();
				
	}); // for each
		
	if (regstatus=="0") // error
	{
		//alert(dbmsg);
		setGCM("");
	}
	else
	{
	    //alert(dbmsg);
		setGCM(gcmKey); // store in local storage
	}
	
	//alert('Reg Status: ' + regstatus + ' - local storage: ' + localStorage.getItem("gcm_id"));
}
  
function onErrorGCMRegister(jqXHR, textStatus, errorThrown)
{
   // alert('Error Register: ' + textStatus + ' - ' + errorThrown);
}

// DELETE USER 

function ajaxGCMDelUser()
{ 
	  var formData = 'userid=' + deviceUuid;
					 
	  var urlData  =  gcmBaseUrl + 'gcm-del.php';
	 
	 $.ajax({
	   type: "POST", 
       url: urlData,
	   dataType: "xml",
	   data: formData,
	   success: onSuccessGCMRemove,
	   error: onErrorGCMRemove
        });

        return false;
}
   
function onSuccessGCMRemove(data)
{
   var regstatus;
   var errmsg;
   var dbmsg;
   
   var $xml   = $( data );
   	 
   $($xml).find("unregister").each(function () {
   
	   regstatus   = $(this).find("status").text();
	   errmsg      = $(this).find("errormsg").text();
	   dbmsg       = $(this).find("dbmsg").text();
				
	}); // for each
	
	if (regstatus=="1") // error
	{
	//	alert(dbmsg);
		setGCM("");
	}
	else // failed to remove
	{
	   // alert(dbmsg);
		setGCM(gcmKey); // store in local storage
	}
}
  
function onErrorGCMRemove(jqXHR, textStatus, errorThrown)
{
   // alert('Error Remove: ' + textStatus + ' - ' + errorThrown);
}